@@ -1,10 +1,10 @@
+package Dist::Zilla::Plugin::FatPacker;
 use 5.008;
 use strict;
 use warnings;
-
-package Dist::Zilla::Plugin::FatPacker;
-$Dist::Zilla::Plugin::FatPacker::VERSION = '1.161630';
 # ABSTRACT: Pack your dependencies onto your script file
+our $VERSION = '1.161631'; # VERSION
+
 use File::Temp 'tempfile';
 use File::Path 'remove_tree';
 use File::pushd 'tempd';
@@ -95,8 +95,7 @@ __END__
 
 =pod
 
-=for test_synopsis 1;
-__END__
+=encoding UTF-8
 
 =head1 NAME
 
@@ -104,7 +103,9 @@ Dist::Zilla::Plugin::FatPacker - Pack your dependencies onto your script file
 
 =head1 VERSION
 
-version 1.161630
+version 1.161631
+
+=for test_synopsis BEGIN { die "SKIP: synopsis isn't perl code" }
 
 =head1 SYNOPSIS
 
@@ -118,8 +119,6 @@ In C<dist.ini>:
 This plugin uses L<App::FatPacker> to pack your dependencies onto your script
 file.
 
-=head1 METHODS
-
 =head2 munge_file
 
 When processing the script file indicated by the C<script> configuration parameter,
@@ -128,38 +127,35 @@ it prepends its packed dependencies to the script.
 This process creates temporary files outside the build directory, but if there
 are no errors, they will be removed again.
 
-=head1 FUNCTIONS
-
 =head2 safe_pipe_command
 
-This runs a command in a pipe, and returns the stdout.
+Runs a command in a pipe, and returns the stdout.
 
 =head2 safe_remove_tree
 
-This is a wrapper around C<remove_tree()> from C<File::Path> that adds some
+A wrapper around C<remove_tree()> from C<File::Path> that adds some
 error checks.
 
 =head2 safe_system
 
-This is a wrapper around C<system()> that adds some error checks.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
-
-=head1 BUGS AND LIMITATIONS
-
-You can make new bug reports, and view existing ones, through the
-web interface at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-FatPacker>.
+A wrapper around C<system()> that adds some error checks.
 
 =head1 AVAILABILITY
 
-The project homepage is L<http://search.cpan.org/dist/Dist-Zilla-Plugin-FatPacker/>.
-
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see L<https://metacpan.org/module/Dist::Zilla::Plugin::FatPacker/>.
 
+=head1 SOURCE
+
+The development version is on github at L<http://github.com/doherty/Dist-Zilla-Plugin-FatPacker>
+and may be cloned from L<git://github.com/doherty/Dist-Zilla-Plugin-FatPacker.git>
+
+=head1 BUGS AND LIMITATIONS
+
+You can make new bug reports, and view existing ones, through the
+web interface at L<https://github.com/doherty/Dist-Zilla-Plugin-FatPacker/issues>.
+
 =head1 AUTHOR
 
 Mike Doherty <doherty@cpan.org>
